@@ -5,7 +5,6 @@ from lxml import etree
 import os
 import re
 import datetime
-from balbec.balbec_twisted import ROOT
 from balbec.objects import Map, Hostgroup, Operation, GroupObject
 
 HOST_UP = 0
@@ -21,6 +20,8 @@ SERVICE_UNKNOWN = 3
 hostStatus = {HOST_UP : "Up", HOST_DOWN : "Down", HOST_UNREACHABLE : "Unreachable", HOST_UNREACHABLE_2 : "Unreachable"}
 serviceStatus = {SERVICE_OK : "Ok", SERVICE_WARNING : "Warning", SERVICE_CRITICAL : "Critical", SERVICE_UNKNOWN : "Unknown"}
 
+ROOT = lambda base : os.path.join(os.path.dirname(__file__), base).replace('\\','/')
+
 class XmlHandler:
 
     def __init__(self, documentRoot):
